@@ -835,7 +835,7 @@ static const ib_field_t ib_mad_f[] = {
 	{BITSOFFS(16, 16), "ThresholdEventCounter", mad_dump_uint},
 	{BITSOFFS(32, 16), "ThresholdCongestionEventMap", mad_dump_hex},
 	/* XXX: Q3/2010 errata lists offset 48, but that means field is not
-	 * world aligned.  Assume will be aligned to offset 64 later.
+	 * word aligned.  Assume will be aligned to offset 64 later.
 	 */
 	{BITSOFFS(64, 32), "CurrentTimeStamp", mad_dump_uint},
 	{0, 0},			/* IB_CC_CONGESTION_LOG_CA_LAST_F */
@@ -858,9 +858,9 @@ static const ib_field_t ib_mad_f[] = {
 	{0, 32, "Control_Map", mad_dump_hex},
 	{32, 256, "Victim_Mask", mad_dump_array},
 	{288, 256, "Credit_Mask", mad_dump_array},
-	{BITSOFFS(544, 4), "Threshold", mad_dump_uint},
+	{BITSOFFS(544, 4), "Threshold", mad_dump_hex},
 	{BITSOFFS(552, 8), "Packet_Size", mad_dump_uint},
-	{BITSOFFS(560, 4), "CS_Threshold", mad_dump_uint},
+	{BITSOFFS(560, 4), "CS_Threshold", mad_dump_hex},
 	{BITSOFFS(576, 16), "CS_ReturnDelay", mad_dump_hex}, /* TODO: CCT dump */
 	{BITSOFFS(592, 16), "Marking_Rate", mad_dump_uint},
 	{0, 0},			/* IB_CC_SWITCH_CONGESTION_SETTING_LAST_F */
@@ -949,8 +949,42 @@ static const ib_field_t ib_mad_f[] = {
 	{480, 32, "Counter14", mad_dump_uint},
 	{0, 0},			/* IB_PSR_LAST_F */
 
-	{0, 0}			/* IB_FIELD_LAST_ */
+	/*
+	 * PortInfoExtended fields
+	 */
+	{0, 32, "CapMask", mad_dump_hex},
+	{BITSOFFS(32, 16), "FECModeActive", mad_dump_uint},
+	{BITSOFFS(48, 16), "FDRFECModeSupported", mad_dump_hex},
+	{BITSOFFS(64, 16), "FDRFECModeEnabled", mad_dump_hex},
+	{BITSOFFS(80, 16), "EDRFECModeSupported", mad_dump_hex},
+	{BITSOFFS(96, 16), "EDRFECModeEnabled", mad_dump_hex},
+	{0, 0},			/* IB_PORT_EXT_LAST_F */
 
+	/*
+	 * PortExtendedSpeedsCounters RSFEC Active fields
+	 */
+	{BITSOFFS(8, 8), "PortSelect", mad_dump_uint},
+	{64, 64, "CounterSelect", mad_dump_hex},
+	{BITSOFFS(128, 16), "SyncHeaderErrorCounter", mad_dump_uint},
+	{BITSOFFS(144, 16), "UnknownBlockCounter", mad_dump_uint},
+	{352, 32, "FECCorrectableSymbolCtrLane0", mad_dump_uint},
+	{384, 32, "FECCorrectableSymbolCtrLane1", mad_dump_uint},
+	{416, 32, "FECCorrectableSymbolCtrLane2", mad_dump_uint},
+	{448, 32, "FECCorrectableSymbolCtrLane3", mad_dump_uint},
+	{480, 32, "FECCorrectableSymbolCtrLane4", mad_dump_uint},
+	{512, 32, "FECCorrectableSymbolCtrLane5", mad_dump_uint},
+	{544, 32, "FECCorrectableSymbolCtrLane6", mad_dump_uint},
+	{576, 32, "FECCorrectableSymbolCtrLane7", mad_dump_uint},
+	{608, 32, "FECCorrectableSymbolCtrLane8", mad_dump_uint},
+	{640, 32, "FECCorrectableSymbolCtrLane9", mad_dump_uint},
+	{672, 32, "FECCorrectableSymbolCtrLane10", mad_dump_uint},
+	{704, 32, "FECCorrectableSymbolCtrLane11", mad_dump_uint},
+	{1120, 32, "PortFECCorrectableBlockCtr", mad_dump_uint},
+	{1152, 32, "PortFECUncorrectableBlockCtr", mad_dump_uint},
+	{1184, 32, "PortFECCorrectedSymbolCtr", mad_dump_uint},
+	{0, 0},			/* IB_PESC_RSFEC_LAST_F */
+
+	{0, 0}			/* IB_FIELD_LAST_ */
 };
 
 static void _set_field64(void *buf, int base_offs, const ib_field_t * f,
